@@ -129,6 +129,7 @@ sub _array_set {
     $subarray->[ $indices->[-1] ] = $val;
 }
 
+
 around qw(slice dice) => sub : lvalue {
     my $orig = shift;
     my $self = shift;
@@ -266,6 +267,12 @@ sub _call_on_pdl {
 }
 
 
+sub where {
+    my ( $self, $mask ) = @_;
+    return $self->slice( which($mask) );
+}
+
+
 for my $method (qw(isbad isgood ngood nbad)) {
     no strict 'refs';
     *{$method} = _call_on_pdl($method);
@@ -310,12 +317,6 @@ sub match_regexp {
     return $p;
 }
 
-
-sub where {
-    my ( $self, $mask ) = @_;
-    return $self->slice( which($mask) );
-}
-
 sub _effective_internal {
     my ($self) = @_;
 
@@ -403,7 +404,7 @@ PDL::SV - PDL subclass for keeping scalar data (like strings)
 
 =head1 VERSION
 
-version 0.0042_01
+version 0.0042_02
 
 =head1 SYNOPSIS
 
@@ -420,7 +421,18 @@ While this class is a subclass of L<PDL>, its internals are quite different
 from other normal PDL types. So basically what's not documented are not
 guarenteed to work.
 
-=head1 METHODS
+=head1 METHODS / BASIC
+
+These methods basically have similar behavior as PDL class's methods of
+same names.
+
+=head2 slice
+
+    slice(...)
+
+=head2 dice
+
+    dice(...)
 
 =head2 glue
 
@@ -463,6 +475,15 @@ BAD values are not considered unique and are ignored.
 
     inplace()
 
+=head2 where
+
+    where($mask)
+
+=head1 METHODS / BAD VALUE
+
+These methods basically have similar behavior as PDL class's methods of
+same names.
+
 =head2 isbad
 
     isbad()
@@ -485,8 +506,14 @@ BAD values are not considered unique and are ignored.
 
 =head2 setbadtoval
 
+    setbadtoval($val)
+
 Cannot be run inplace.
 
+=head1 METHODS / ADDITIONAL
+
+These methods exist not in PDL but only in this class.
+
 =head2 match_regexp
 
     match_regexp($pattern)
@@ -494,10 +521,6 @@ Cannot be run inplace.
 Match against a plain a regular expression.
 Returns a piddle of the same dimension.
 
-=head2 where
-
-    where($mask)
-
 =head1 SEE ALSO
 
 L<PDL>
