@@ -6,14 +6,14 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.0042_01'; # TRIAL VERSION
+our $VERSION = '0.0042_02'; # TRIAL VERSION
 
 use Safe::Isa;
 use Test2::API qw/context/;
 use Test2::Util::Table qw/table/;
 use Test2::Util::Ref qw/render_ref/;
 
-use parent qw/Exporter/;
+use parent qw(Exporter::Tiny);
 our @EXPORT = qw(dataframe_ok dataframe_is);
 
 
@@ -109,7 +109,7 @@ Test2::Tools::DataFrame - Tools for verifying Data::Frame data frames
 
 =head1 VERSION
 
-version 0.0042_01
+version 0.0042_02
 
 =head1 SYNOPSIS
 
